<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\InterviewSlot;
use Illuminate\Support\Facades\Mail;
use App\Models\User;
use Illuminate\Support\Facades\Validator;
use Carbon\Carbon;
use Auth;
class InterviewSlotController extends Controller
{

    public function index($status= ""){
        

          $mytime = Carbon::now();
          $c_date= $mytime->toDateString();
        if($status == "all"):
            $dat = InterviewSlot::get(); 
            $title = "All Interview Slots";
        endif;
        $tip = User::where('user_type' , 'tip')->get();
        return view('admin.interview-slots.index' , compact('dat' , 'tip' , 'status' , 'title'));
    }


    public function store(Request $request){
        $mytime = Carbon::now();
        $c_date= $mytime->toDateString();

        $rules =
            [
              'date'=>"required|after:$c_date",
              'time' =>'required',
              'zoom_link' =>'required',
              'interviewer_primary_id' =>'required',
              'interviewer_secondary_id' =>'required',
              'interviewer_tertiary_id' =>'required',
            ];
            $message = [
               'date.required' => 'Date is required',
               'time.required' =>'Time is required',
               'zoom_link.required' =>'Zoom Link is required',
               'interviewer_primary_id.required' =>'Primary Interviewer is required',
               'interviewer_secondary_id.required' =>'Secondary Interviewer is required',
               'interviewer_tertiary_id.required' =>'Tertiary Interviewer is required',
            ]
        ;
        $validator = Validator::make($request->all(), $rules, $message);

        if ($validator->fails()) {
            return back()->withInput()->withErrors($validator->getMessageBag())->with([
                'status'=>'add',
                'modal' => 'modelnew',
            ]);
        }
      
      
        $input = $request->all();
       
        $slot = new InterviewSlot();
        $input['date'] = $slot->set_date($input['date']);
        $input['status'] ="P";
        $slot->fill($input);
        $slot->save();
        return back()->with("success", "Added Successfully");
    }

    public function update(Request $request , $id){
        $rules =
            [
              'date'=>"required",
              'time' =>'required',
              'zoom_link' =>'required',
              'interviewer_primary_id' =>'required',
              'interviewer_secondary_id' =>'required',
              'interviewer_tertiary_id' =>'required',
            ];
            $message = [
               'date.required' => 'Date is required',
               'time.required' =>'Time is required',
               'zoom_link.required' =>'Zoom Link is required',
               'interviewer_primary_id.required' =>'Primary Interviewer is required',
               'interviewer_secondary_id.required' =>'Secondary Interviewer is required',
               'interviewer_tertiary_id.required' =>'Tertiary Interviewer is required',
            ]
        ;

        $validator = Validator::make($request->all(), $rules, $message);

        if ($validator->fails()) {
            return back()->with(['errors' => $validator->getMessageBag()->toArray()]);
        }
       

            $input = $request->all();
            $input['status'] = "P";
            $slot = InterviewSlot::findOrFail($id);
            if($request->date)
                $input['date'] = $slot->set_date($input['date']);
            $slot->fill($input);
            $slot->update();
            return back()->with("success", "Updated Successfully");
        
        
      
    }


    public function status(Request $request , $id , $status){
        $slot = InterviewSlot::findOrFail($id);
        $slot->status = $status;
        $slot->updated_by = Auth::user()->id;
        if($request->cancel_reason){
            $slot->cancel_reason = $request->cancel_reason;
        }
        $slot->update();
        if($slot->interviewee_id != null){
            $user = User::find($slot->interviewee_id);
            $cname = $user->first_name;
            $to = $user->email;
            if($slot->status == "A"){
                $subject="Interview Slot Accepted";
                $text="Interview Slot has been Accepted";
                $dec="Interview Slot has been Accepted Prepare yourself for interview";
                $link = route('login');
            }else if($slot->status == "D"){
                $subject="Interview Slot Rejected";
                $text="Select another slot";
                $dec="Interview Slot has been Rejected. Select another slot";
                $link = route('volunteer.interview-slots.index' , 'all');
            }else if($slot->status == "C"){
                $subject="Interview Slot Cancelled";
                $text="Select another slot";
                $dec="Interview Slot has been Cancelled. Select another slot";
                $link = route('volunteer.interview-slots.index' , 'all');
            }
    
            Mail::send('email.application', ['cname' => $cname, 'dec'=>$dec ,'text' => $text, 'link' => $link], function ($message) use ($cname , $to , $subject) {
                $message->to($to , $cname);
                $message->subject($subject);
                $message->from(env('MAIL_FROM_ADDRESS') , 'Tip User');
           });
        }

        return back()->with("success", "Updated Successfully");
    }

    public function show(){

    }

    public function destroy($id){
        InterviewSlot::find($id)->delete();
        return back()->with("success", "Deleted Successfully");

    }

}