<?php

use Illuminate\Support\Facades\Route;
use App\Http\Controllers\Admin\ApplicationController;
use App\Http\Controllers\Volunteer\ApplyController;
use App\Http\Controllers\Admin\CompaniesController;
use App\Http\Controllers\Admin\ClientsController;
use App\Http\Controllers\Admin\TicketsController;
use App\Http\Controllers\Admin\InterviewSlotController;


/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::get('/', function () {
    return view('welcome');
});
Route::get('/main', function () {
    return view('admin.master');
});
Route::prefix('/client')->group(function(){      
    Route::get('/register', function () {
        return view('auth.client_register');
    });
});

Route::prefix('/caregiver')->group(function(){      
    Route::get('/register', function () {
        return view('auth.caregiver_register');
    });
});
Route::group(['middleware' => 'auth'], function(){
    Route::namespace('App\Http\Controllers\Admin')->name('admin.')->prefix('admin')->middleware('role:Admin')->group(function(){
        Route::resource('/languages' , LanguageController::class);
        // Route::resource('/interview-slots' , InterviewSlotController::class)->except('index');
        Route::get('/interview-slots/{status}' , [App\Http\Controllers\Admin\InterviewSlotController::class , 'index'])->name('interview.slots.index');
        Route::delete('/interview-slots/{id}' , [App\Http\Controllers\Admin\InterviewSlotController::class , 'destroy'])->name('interview.slots.destroy');
        Route::post('/interview-slots' , [App\Http\Controllers\Admin\InterviewSlotController::class , 'store'])->name('interview-slots.store');
        Route::put('/interview-slots/{id}' , [App\Http\Controllers\Admin\InterviewSlotController::class , 'update'])->name('interview-slots.update');
        Route::post('/interview-slots/{id}/{status}' , [App\Http\Controllers\Admin\InterviewSlotController::class , 'status'])->name('interview.slots.status');
        Route::get('/applications/{status}' , [App\Http\Controllers\Admin\ApplicationController::class , 'applications'])->name('applications.index');
        Route::get('/applications-queue' , [App\Http\Controllers\Admin\ApplicationController::class , 'application_queue'])->name('applications.queue');
        Route::get('/applicaion-detail/{id}' , [App\Http\Controllers\Admin\ApplicationController::class , 'app_show'])->name('application.show');
        Route::get('/applicaion-accept/{id}' , [App\Http\Controllers\Admin\ApplicationController::class , 'app_accept'])->name('application.accept');
        Route::get('/applicaion-hold/{id}' , [App\Http\Controllers\Admin\ApplicationController::class , 'app_hold'])->name('application.hold');
        Route::post('/applicaion-interviewee' , [App\Http\Controllers\Admin\ApplicationController::class , 'interviewee_accept'])->name('application.interview_accept');
        Route::post('/applicaion-interviewee_hold' , [App\Http\Controllers\Admin\ApplicationController::class , 'interviewee_hold'])->name('application.interview_hold');
        Route::put('/applicaion-status/{id}/{status}' , [App\Http\Controllers\Admin\ApplicationController::class , 'app_status'])->name('application.status');
        Route::resource('/training' , TrainingController::class);
        Route::get('/closed-training' , [App\Http\Controllers\Admin\TrainingController::class , 'closed'])->name('training.closed');
        Route::post('/training-add-trainee' ,[ App\Http\Controllers\Admin\TrainingController::class, 'add_trainee'])->name('training.add_trainee');
        Route::get('/training-show-trainee/{id}' ,[ App\Http\Controllers\Admin\TrainingController::class, 'show_trainee'])->name('training.show_trainee');
        Route::get('/training-postpone/{id}' ,[ App\Http\Controllers\Admin\TrainingController::class, 'batch_postpone'])->name('training.postpone');
        Route::Post('/training-trainee_del' ,[ App\Http\Controllers\Admin\TrainingController::class, 'batch_trainee_del'])->name('training.delete_trainee');
        Route::post('/training-trainer' ,[ App\Http\Controllers\Admin\TrainingController::class, 'batch_trainer'])->name('training.trainer');
        Route::get('/training-trainee_check' ,[ App\Http\Controllers\Admin\TrainingController::class, 'trainee_check'])->name('training.trainee_check');
        Route::get('/volunteer_mail/{id}/{status}' , [App\Http\Controllers\Admin\ApplicationController::class , 'form_fill'])->name('application.volunteer_form');
        // Route::get('/volunteer' , [App\Http\Controllers\Admin\VolunteerController::class , 'index'])->name('volunteer.index');
        Route::get('/apply' , [App\Http\Controllers\Admin\VolunteerController::class , 'index'])->name('volunteer');
        Route::resource('/users',UsersController::class );
        Route::get('/companies' , [App\Http\Controllers\Admin\CompaniesController::class , 'index'])->name('companies');
        Route::get('/clients' , [App\Http\Controllers\Admin\ClientsController::class , 'index'])->name('client.index');
        Route::get('/tickets' , [App\Http\Controllers\Admin\TicketsController::class , 'index'])->name('tickets');
        Route::post('/client-screening' , [App\Http\Controllers\Admin\ClientsController::class , 'screening'])->name('client.screening');
        Route::post('/client-screening/{status}' , [App\Http\Controllers\Admin\ClientsController::class , 'action_store'])->name('client.store');
        Route::get('/volunteer_color' , [App\Http\Controllers\Admin\ClientsController::class , 'check_volntr_colr'])->name('volntr.color');
        Route::get('/client-queue' , [App\Http\Controllers\Admin\ClientsController::class , 'client_queue'])->name('client.queue');
        Route::resource('batches' , App\Http\Controllers\Admin\BatchesController::class);
        Route::get('/volunteer' , [App\Http\Controllers\Admin\VolunteerController::class , 'index'])->name('volunteer.index');
        Route::post('/filter-volunteer' , [App\Http\Controllers\Admin\VolunteerController::class , 'filter'])->name('volunteer.filter');
        Route::get('/unregistered-volunteer' , [App\Http\Controllers\Admin\VolunteerController::class , 'unregistered'])->name('volunteer.unregistered');
        Route::get('/onhold-volunteer' , [App\Http\Controllers\Admin\VolunteerController::class , 'onhold'])->name('volunteer.onhold');
        Route::put('volunteer-skill/{id}' , [App\Http\Controllers\Admin\VolunteerController::class , 'skill'])->name('volunteer.skill');
        Route::put('volunteer-contract/{id}' , [App\Http\Controllers\Admin\VolunteerController::class , 'contract'])->name('volunteer.contract');
        Route::put('register/{id}/{status}' , [App\Http\Controllers\Admin\VolunteerController::class , 'register'])->name('volunteer.register');
        Route::put('hold/{id}/{status}' , [App\Http\Controllers\Admin\VolunteerController::class , 'hold'])->name('volunteer.hold');
        Route::put('active/{id}/{status}' , [App\Http\Controllers\Admin\VolunteerController::class , 'active'])->name('volunteer.active');
        Route::put('task/{id}' , [App\Http\Controllers\Admin\VolunteerController::class , 'task'])->name('volunteer.task');
        Route::get('client_check' ,[App\Http\Controllers\Admin\VolunteerController::class , 'client'])->name('volunteer.client');
        Route::put('/training-dropout/{id}' ,[ App\Http\Controllers\Admin\TrainingController::class, 'batch_dropout'])->name('training.dropout');
        Route::put('/training-update/{id}' ,[ App\Http\Controllers\Admin\TrainingController::class, 'batch_update'])->name('training.update');
        Route::get('/QAcalls' , [App\Http\Controllers\Admin\ClientsController::class , 'QAcalls'])->name('client.qacalls');
        Route::get('/emergency-contact' , [App\Http\Controllers\Admin\ClientsController::class , 'emergency_contact'])->name('client.emergency.contact');
        Route::put('/client-dropout/{id}' , [App\Http\Controllers\Admin\ClientsController::class , 'client_dropout'])->name('client.dropout');
        Route::put('/client-instruction/{id}' , [App\Http\Controllers\Admin\ClientsController::class , 'client_instruction'])->name('client.instruction');
        

      

        Route::get('quality-asssurance-calls' , function(){
            return view('admin.calls.qcalls');
        })->name('qcalls');
        Route::get('empathy-calls' , function(){
            return view('admin.calls.index');
        })->name('emoathy.calls');
        Route::get('client-screening' , function(){
            return view('admin.clients.client_screening');
        })->name('client.screening');
    });
    Route::prefix('volunteer')->name('volunteer.')->middleware('role:volunteer' , 'verified')->group(function(){
        Route::resource('apply' , App\Http\Controllers\Volunteer\ApplicationController::class);
        Route::get('form-one' , [App\Http\Controllers\Volunteer\ApplicationController::class , 'form_one'])->name('form.one');
        Route::get('form-two' , [App\Http\Controllers\Volunteer\ApplicationController::class , 'form_two'])->name('form.two');
        Route::post('form-one' , [App\Http\Controllers\Volunteer\ApplicationController::class , 'store_form_one'])->name('form.one.store');
        Route::post('form-two' , [App\Http\Controllers\Volunteer\ApplicationController::class , 'store_form_two'])->name('form.two.store');
        Route::get('form-three' , [App\Http\Controllers\Volunteer\ApplicationController::class , 'form_three'])->name('form.three');
        Route::post('form-three' , [App\Http\Controllers\Volunteer\ApplicationController::class , 'store_form_three'])->name('form.three.store');
        Route::get('/interview-slots/{status}' , [App\Http\Controllers\Volunteer\InterviewSlotController::class , 'index'])->name('interview-slots.index');
        Route::put('/interview-slots/status/{id}{status}' , [App\Http\Controllers\Volunteer\InterviewSlotController::class , 'status'])->name('interview-slots.status');
        Route::get('training-batch/{id?}' , [App\Http\Controllers\Volunteer\TrainingController::class , 'all_batch'])->name('training.index');
        Route::get('ctraining-batch/{batchid?}' , [App\Http\Controllers\Volunteer\TrainingController::class , 'confirm_batch'])->name('training.confirm');
        Route::resource('feedback' , App\Http\Controllers\Volunteer\TrainingFeedbackController::class);
        Route::get('client' , [App\Http\Controllers\Volunteer\ClientController::class , 'index'])->name('client.index');
    });
    Route::prefix('tip')->name('tip.')->middleware('role:tip')->group(function(){
        Route::resource('batches' , App\Http\Controllers\TipUser\BatchesController::class);
        Route::get('/volunteer/{id}' , [App\Http\Controllers\TipUser\VolunteerController::class , 'index'])->name('volunteer.index');
        Route::put('volunteer-skill/{id}' , [App\Http\Controllers\TipUser\VolunteerController::class , 'skill'])->name('volunteer.skill');
        Route::put('volunteer-contract/{id}' , [App\Http\Controllers\TipUser\VolunteerController::class , 'contract'])->name('volunteer.contract');
        Route::resource('session' , App\Http\Controllers\TipUser\DropinSessionController::class );
        Route::post('session_detail' , [App\Http\Controllers\TipUser\DropinSessionController::class , 'session_detail'])->name('session.detail');
        Route::put('register/{id}/{status}' , [App\Http\Controllers\TipUser\VolunteerController::class , 'register'])->name('volunteer.register');
        Route::put('hold/{id}/{status}' , [App\Http\Controllers\TipUser\VolunteerController::class , 'hold'])->name('volunteer.hold');
        Route::put('active/{id}/{status}' , [App\Http\Controllers\TipUser\VolunteerController::class , 'active'])->name('volunteer.active');
        Route::put('task/{id}' , [App\Http\Controllers\TipUser\VolunteerController::class , 'task'])->name('volunteer.task');
        Route::post('volunteer-notes/{id?}' , [App\Http\Controllers\TipUser\VolunteerController::class , 'volunteer_notes'])->name('volunteer.notes');
        Route::put('volunteer_close/{id}' , [App\Http\Controllers\TipUser\VolunteerController::class , 'volunteer_close'])->name('volunteer.close');
        Route::put('client_check' ,[App\Http\Controllers\TipUser\VolunteerController::class , 'client'])->name('volunteer.client');


    });   
    Route::prefix('client')->name('client.')->middleware('role:client')->group(function(){
        Route::get('referal' , [App\Http\Controllers\Client\ClientController::class , 'index'])->name('referal.index');
        Route::post('referal-store' , [App\Http\Controllers\Client\ClientController::class,'store'])->name('referal.store');
        Route::get('ticket' , [App\Http\Controllers\Client\TicketController::class,'index'])->name('ticket.index');
        Route::get('ticket-store' , [App\Http\Controllers\Client\TicketController::class,'store'])->name('ticket.store');
        Route::get('ticket-show' , [App\Http\Controllers\Client\TicketController::class,'show'])->name('ticket.show');
        Route::get('contact' , [App\Http\Controllers\Caregiver\ContactController::class,'index'])->name('contact.index');
    });



    Route::prefix('caregiver')->name('caregiver.')->middleware('role:caregiver' , 'verified')->group(function(){
        Route::get('referal' , [App\Http\Controllers\Caregiver\ClientController::class , 'index'])->name('referal.index');
        Route::get('referal-store' , [App\Http\Controllers\Caregiver\ClientController::class,'store'])->name('referal.store');
        Route::get('ticket' , [App\Http\Controllers\Caregiver\TicketController::class,'index'])->name('ticket.index');
        Route::get('ticket-store' , [App\Http\Controllers\Caregiver\TicketController::class,'store'])->name('ticket.store');
        Route::get('ticket-show' , [App\Http\Controllers\Caregiver\TicketController::class,'show'])->name('ticket.show');
    
    });
});

Auth::routes();
Route::get('/home', [App\Http\Controllers\HomeController::class, 'index'])->name('home');
Route::get('/email/verify', [App\Http\Controllers\Auth\VerificationController::class, 'show'])->name('verification.notice');
Route::get('/email/verify/{id}/{hash}', [App\Http\Controllers\Auth\VerificationController::class, 'verify'])->name('verification.verify')->middleware(['signed']);
Route::post('/email/resend', [App\Http\Controllers\Auth\VerificationController::class, 'resend'])->name('verification.resend');
